Wrap

Enum Wrap 

pub enum Wrap<T32, T64> {
    T32(T32),
    T64(T64),
}
Wraps 32-bit and 64-bit variants.

Variants



T32(T32)



T64(T64)

Implementations

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Pe32, Pe64>

pub fn image(&self) -> &'a [u8]

pub fn align(&self) -> Align

pub fn as_ref(&self) -> Wrap<&Pe32, &Pe64>

pub fn dos_header(&self) -> &'a IMAGE_DOS_HEADER

pub fn dos_image(&self) -> &'a [u8]

pub fn nt_headers(&self) -> Wrap<&'a IMAGE_NT_HEADERS32, &'a IMAGE_NT_HEADERS64>

pub fn file_header(&self) -> &'a IMAGE_FILE_HEADER

pub fn optional_header( &self, ) -> Wrap<&'a IMAGE_OPTIONAL_HEADER32, &'a IMAGE_OPTIONAL_HEADER64>

pub fn data_directory(&self) -> &'a [IMAGE_DATA_DIRECTORY]

pub fn section_headers(&self) -> &'a SectionHeaders

pub fn slice(&self, rva: u32, min_size: usize, align: usize) -> Result<&'a [u8]>

pub fn slice_bytes(&self, rva: u32) -> Result<&'a [u8]>

pub fn get_section_bytes( &self, section_header: &IMAGE_SECTION_HEADER, ) -> Result<&'a [u8]>

pub fn derva<T>(&self, rva: u32) -> Result<&'a T>
where T: Pod,

pub fn derva_copy<T>(&self, rva: u32) -> Result<T>
where T: Copy + Pod,

pub fn derva_into<T>(&self, rva: u32, dest: &mut T) -> Result<()>
where T: ?Sized + Pod,

pub fn derva_slice<T>(&self, rva: u32, len: usize) -> Result<&'a [T]>
where T: Pod,

pub fn derva_slice_f<T, F>(&self, rva: u32, f: F) -> Result<&'a [T]>
where T: Pod, F: FnMut(&'a T) -> bool,

pub fn derva_slice_s<T>(&self, rva: u32, sentinel: T) -> Result<&'a [T]>
where T: PartialEq + Pod,

pub fn derva_c_str(&self, rva: u32) -> Result<&'a CStr>

pub fn derva_string<T>(&self, rva: u32) -> Result<&'a T>
where T: FromBytes + ?Sized,

pub fn headers(&self) -> Wrap<Headers<Pe32>, Headers<Pe64>>

pub fn rich_structure(&self) -> Result<RichStructure<'a>>

pub fn exports(&self) -> Result<Wrap<Exports<'a, Pe32>, Exports<'a, Pe64>>>

pub fn imports(&self) -> Result<Wrap<Imports<'a, Pe32>, Imports<'a, Pe64>>>

pub fn iat(&self) -> Result<Wrap<IAT<'a, Pe32>, IAT<'a, Pe64>>>

pub fn base_relocs(&self) -> Result<BaseRelocs<'a>>

pub fn load_config( &self, ) -> Result<Wrap<LoadConfig<'a, Pe32>, LoadConfig<'a, Pe64>>>

pub fn tls(&self) -> Result<Wrap<Tls<'a, Pe32>, Tls<'a, Pe64>>>

pub fn security(&self) -> Result<Security<'a>>

pub fn exception( &self, ) -> Result<Wrap<Exception<'a, Pe32>, Exception<'a, Pe64>>>

pub fn debug(&self) -> Result<Wrap<Debug<'a, Pe32>, Debug<'a, Pe64>>>

pub fn resources(&self) -> Result<Resources<'a>>

pub fn scanner(&self) -> Wrap<Scanner<Pe32>, Scanner<Pe64>>

Source

impl<'a> Wrap<PeView<'a>, PeView<'a>>

pub fn from_bytes<T: AsRef<[u8]> + ?Sized>(image: &'a T) -> Result<PeView<'a>>

Source

impl<'a> Wrap<PeFile<'a>, PeFile<'a>>

pub fn from_bytes<T: AsRef<[u8]> + ?Sized>(image: &'a T) -> Result<PeFile<'a>>

Constructs a PeFile from byte slice.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Headers<Pe32>, Headers<Pe64>>

Describes the PE headers.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> &'a [u8]

Gets the PE headers as a byte slice.

pub fn check_sum(&self) -> u32

Calculates the optional header’s CheckSum.

pub fn code_range(&self) -> Range<u32>

Gets the code range from the optional header.

pub fn image_range(&self) -> Range<u32>

Gets the full image range excluding the PE headers.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Exports<'a, Pe32>, Exports<'a, Pe64>>

Export directory.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> &'a IMAGE_EXPORT_DIRECTORY

Returns the underlying export directory image.

pub fn dll_name(&self) -> Result<&'a CStr>

Gets the export directory’s name for this library.

pub fn ordinal_base(&self) -> u16

Gets the ordinal base for the exported functions.

pub fn functions(&self) -> Result<&'a [u32]>

Gets the export address table.

pub fn names(&self) -> Result<&'a [u32]>

Gets the name address table.

pub fn name_indices(&self) -> Result<&'a [u16]>

Gets the name index table.

pub fn by(&self) -> Result<Wrap<By<'a, Pe32>, By<'a, Pe64>>>

Query the exports.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<By<'a, Pe32>, By<'a, Pe64>>

Export directory symbol lookup.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> &'a IMAGE_EXPORT_DIRECTORY

Returns the underlying export directory image.

pub fn dll_name(&self) -> Result<&'a CStr>

Gets the export directory’s name for this library.

pub fn ordinal_base(&self) -> u16

Gets the ordinal base for the exported functions.

pub fn functions(&self) -> &'a [u32]

Gets the export address table.

pub fn names(&self) -> &'a [u32]

Gets the name address table.

pub fn name_indices(&self) -> &'a [u16]

Gets the name index table.

pub fn check_sorted(&self) -> Result<bool>

Validates and checks if the name table is sorted.

pub fn ordinal(&self, ordinal: u16) -> Result<Export<'a>>

Looks up an Export by its ordinal.

pub fn name_linear<S: AsRef<[u8]> + ?Sized>( &self, name: &S, ) -> Result<Export<'a>>

Looks up an Export by its name.

pub fn name<S: AsRef<[u8]> + ?Sized>(&self, name: &S) -> Result<Export<'a>>

Looks up an Export by its name.

pub fn import(&self, import: Import<'_>) -> Result<Export<'a>>

Looks up an Export by its import.

pub fn index(&self, index: usize) -> Result<Export<'a>>

Looks up an export by its index.

pub fn hint(&self, hint: usize) -> Result<Export<'a>>

Looks up an export by its hint.

pub fn hint_name<S: AsRef<[u8]> + ?Sized>( &self, hint: usize, name: &S, ) -> Result<Export<'a>>

Looks up an export by its hint and falls back to the name if the hint is incorrect.

pub fn name_of_hint(&self, hint: usize) -> Result<&'a CStr>

Looks up the name for a hint.

pub fn name_lookup(&self, index: usize) -> Result<Import<'a>>

Given an index in the functions array, gets the named export.

pub fn iter<'s>( &'s self, ) -> impl 's + Clone + Iterator<Item = Result<Export<'a>>>

Iterate over exported functions.

pub fn iter_names<'s>( &'s self, ) -> impl 's + Clone + Iterator<Item = (Result<&'a CStr>, Result<Export<'a>>)>

Iterate over functions exported by name.

pub fn iter_name_indices<'s>( &'s self, ) -> impl 's + Clone + Iterator<Item = (Result<&'a CStr>, usize)>

Iterate over functions exported by name, returning their name and index in the functions table.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Pe32, Pe64>

Convenient way to get an exported address.

pub fn get_export_by_ordinal(&self, ordinal: u16) -> Result<Export<'a>>

Convenient method to get an exported function by ordinal.

pub fn get_export_by_import(&self, import: Import<'a>) -> Result<Export<'a>>

Convenient method to get an exported function by import.

pub fn get_export_by_name<S: ?Sized + AsRef<[u8]>>( &self, name: &S, ) -> Result<Export<'a>>

Convenient method to get an exported function by name.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Imports<'a, Pe32>, Imports<'a, Pe64>>

Import directory.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> &'a [IMAGE_IMPORT_DESCRIPTOR]

Returns the underlying import directory image array.

pub fn iter(&self) -> Wrap<Iter<'a, Pe32>, Iter<'a, Pe64>>

Iterator over the import descriptors.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<IAT<'a, Pe32>, IAT<'a, Pe64>>

Import Address Table.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> Wrap<&'a [u32], &'a [u64]>

Returns the underlying iat array.

pub fn iter( &self, ) -> Wrap<impl Clone + Iterator<Item = (&'a u32, Result<Import<'a>>)>, impl Clone + Iterator<Item = (&'a u64, Result<Import<'a>>)>>

Iterate over the IAT.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Desc<'a, Pe32>, Desc<'a, Pe64>>

Import library descriptor.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> &'a IMAGE_IMPORT_DESCRIPTOR

Returns the underlying import descriptor image.

pub fn dll_name(&self) -> Result<&'a CStr>

Gets the name of the DLL imported from.

pub fn iat(&self) -> Result<Wrap<Iter<'a, u32>, Iter<'a, u64>>>

Gets the import address table.

pub fn int(&self) -> Result<impl Clone + Iterator<Item = Result<Import<'a>>>>

Gets the import name table.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<LoadConfig<'a, Pe32>, LoadConfig<'a, Pe64>>

Load Config Directory.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image( &self, ) -> Wrap<&'a IMAGE_LOAD_CONFIG_DIRECTORY32, &'a IMAGE_LOAD_CONFIG_DIRECTORY64>

Returns the underlying load config directory image.

Gets the default security cookie for the image.

pub fn se_handler_table(&self) -> Result<Wrap<&'a [u32], &'a [u64]>>

Gets the structured exception handler table.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Tls<'a, Pe32>, Tls<'a, Pe64>>

TLS Directory.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image( &self, ) -> Wrap<&'a IMAGE_TLS_DIRECTORY32, &'a IMAGE_TLS_DIRECTORY64>

Returns the underlying TLS directory image.

pub fn raw_data(&self) -> Result<&'a [u8]>

Gets the raw TLS initialization data.

pub fn slot(&self) -> Result<&'a u32>

Gets the TLS slot location.

pub fn callbacks(&self) -> Result<Wrap<&'a [u32], &'a [u64]>>

Gets the TLS initialization callbacks.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Debug<'a, Pe32>, Debug<'a, Pe64>>

Debug directory.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> &'a [IMAGE_DEBUG_DIRECTORY]

Returns the underlying debug directories image.

pub fn pdb_file_name(&self) -> Option<&'a CStr>

Gets the CodeView PDB file name.

pub fn iter(&self) -> Wrap<Iter<'a, Pe32>, Iter<'a, Pe64>>

Iterator over the debug directories.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Dir<'a, Pe32>, Dir<'a, Pe64>>

Debug directory entry.

pub fn pe(&self) -> Wrap<Pe32, Pe64>

Gets the PE instance.

pub fn image(&self) -> &'a IMAGE_DEBUG_DIRECTORY

Gets the underlying debug directory image.

pub fn data(&self) -> Option<&'a [u8]>

Gets the raw data of this debug directory entry.

pub fn entry(&self) -> Result<Entry<'a>>

Interprets the directory entry.

Source

impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Scanner<Pe32>, Scanner<Pe64>>

Pattern scanner.

pub fn finds(&self, pat: &[Atom], range: Range<u32>, save: &mut [u32]) -> bool

Finds the unique match for the pattern in the given range.

pub fn finds_code(&self, pat: &[Atom], save: &mut [u32]) -> bool

Finds the unique code match for the pattern.

pub fn matches<'pat>( &self, pat: &'pat [Atom], range: Range<u32>, ) -> Wrap<Matches<'pat, Pe32>, Matches<'pat, Pe64>>

Returns an iterator over the matches of a pattern within the given range.

pub fn matches_code<'pat>( &self, pat: &'pat [Atom], ) -> Wrap<Matches<'pat, Pe32>, Matches<'pat, Pe64>>

Returns an iterator over the code matches of a pattern.

pub fn exec(&self, cursor: u32, pat: &[Atom], save: &mut [u32]) -> bool

Pattern interpreter, returns if the pattern matches the binary image at the given rva.

Source

impl<'a, 'pat, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Matches<'pat, Pe32>, Matches<'pat, Pe64>>

pub fn scanner(&self) -> Wrap<Scanner<Pe32>, Scanner<Pe64>>

Gets the scanner instance.

pub fn pattern(&self) -> &'pat [Atom]

Gets the pattern.

pub fn range(&self) -> Range<u32>

Gets the remaining range to scan.

pub fn hits(&self) -> u32

Performance counter.

pub fn next(&mut self, save: &mut [u32]) -> bool

Finds the next match with the given save array.

Source

impl<T32, T64> Wrap<Result<T32>, Result<T64>>

pub fn transpose(self) -> Result<Wrap<T32, T64>>

Transposes a wrap of results in a result of a wrap.

Source

impl<T32, T64> Wrap<Option<T32>, Option<T64>>

pub fn transpose(self) -> Option<Wrap<T32, T64>>

Transposes a wrap of options in an option of a wrap.

Source

impl<T> Wrap<T, T>

pub fn into(self) -> T

Unwraps the wrapped value of equal types.