pub enum Wrap<T32, T64> {
T32(T32),
T64(T64),
}Expand description
Wraps 32-bit and 64-bit variants.
Variants
Implementations
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Pe32, Pe64>
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Pe32, Pe64>
pub fn image(&self) -> &'a [u8] ⓘ
pub fn align(&self) -> Align
pub fn as_ref(&self) -> Wrap<&Pe32, &Pe64> ⓘ
pub fn dos_header(&self) -> &'a IMAGE_DOS_HEADER
pub fn dos_image(&self) -> &'a [u8] ⓘ
pub fn nt_headers(&self) -> Wrap<&'a IMAGE_NT_HEADERS32, &'a IMAGE_NT_HEADERS64> ⓘ
pub fn file_header(&self) -> &'a IMAGE_FILE_HEADER
pub fn optional_header( &self, ) -> Wrap<&'a IMAGE_OPTIONAL_HEADER32, &'a IMAGE_OPTIONAL_HEADER64> ⓘ
pub fn data_directory(&self) -> &'a [IMAGE_DATA_DIRECTORY]
pub fn section_headers(&self) -> &'a SectionHeaders
pub fn slice(&self, rva: u32, min_size: usize, align: usize) -> Result<&'a [u8]>
pub fn slice_bytes(&self, rva: u32) -> Result<&'a [u8]>
pub fn get_section_bytes( &self, section_header: &IMAGE_SECTION_HEADER, ) -> Result<&'a [u8]>
pub fn derva<T>(&self, rva: u32) -> Result<&'a T>where
T: Pod,
pub fn derva_copy<T>(&self, rva: u32) -> Result<T>
pub fn derva_into<T>(&self, rva: u32, dest: &mut T) -> Result<()>
pub fn derva_slice<T>(&self, rva: u32, len: usize) -> Result<&'a [T]>where
T: Pod,
pub fn derva_slice_f<T, F>(&self, rva: u32, f: F) -> Result<&'a [T]>
pub fn derva_slice_s<T>(&self, rva: u32, sentinel: T) -> Result<&'a [T]>
pub fn derva_c_str(&self, rva: u32) -> Result<&'a CStr>
pub fn derva_string<T>(&self, rva: u32) -> Result<&'a T>
pub fn headers(&self) -> Wrap<Headers<Pe32>, Headers<Pe64>> ⓘ
pub fn rich_structure(&self) -> Result<RichStructure<'a>>
pub fn exports(&self) -> Result<Wrap<Exports<'a, Pe32>, Exports<'a, Pe64>>>
pub fn imports(&self) -> Result<Wrap<Imports<'a, Pe32>, Imports<'a, Pe64>>>
pub fn iat(&self) -> Result<Wrap<IAT<'a, Pe32>, IAT<'a, Pe64>>>
pub fn base_relocs(&self) -> Result<BaseRelocs<'a>>
pub fn load_config( &self, ) -> Result<Wrap<LoadConfig<'a, Pe32>, LoadConfig<'a, Pe64>>>
pub fn tls(&self) -> Result<Wrap<Tls<'a, Pe32>, Tls<'a, Pe64>>>
pub fn security(&self) -> Result<Security<'a>>
pub fn exception( &self, ) -> Result<Wrap<Exception<'a, Pe32>, Exception<'a, Pe64>>>
pub fn debug(&self) -> Result<Wrap<Debug<'a, Pe32>, Debug<'a, Pe64>>>
pub fn resources(&self) -> Result<Resources<'a>>
pub fn scanner(&self) -> Wrap<Scanner<Pe32>, Scanner<Pe64>> ⓘ
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Headers<Pe32>, Headers<Pe64>>
Describes the PE headers.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Headers<Pe32>, Headers<Pe64>>
Describes the PE headers.
Sourcepub fn code_range(&self) -> Range<u32>
pub fn code_range(&self) -> Range<u32>
Gets the code range from the optional header.
Sourcepub fn image_range(&self) -> Range<u32>
pub fn image_range(&self) -> Range<u32>
Gets the full image range excluding the PE headers.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Exports<'a, Pe32>, Exports<'a, Pe64>>
Export directory.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Exports<'a, Pe32>, Exports<'a, Pe64>>
Export directory.
Sourcepub fn image(&self) -> &'a IMAGE_EXPORT_DIRECTORY
pub fn image(&self) -> &'a IMAGE_EXPORT_DIRECTORY
Returns the underlying export directory image.
Sourcepub fn ordinal_base(&self) -> u16
pub fn ordinal_base(&self) -> u16
Gets the ordinal base for the exported functions.
Sourcepub fn name_indices(&self) -> Result<&'a [u16]>
pub fn name_indices(&self) -> Result<&'a [u16]>
Gets the name index table.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<By<'a, Pe32>, By<'a, Pe64>>
Export directory symbol lookup.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<By<'a, Pe32>, By<'a, Pe64>>
Export directory symbol lookup.
Sourcepub fn image(&self) -> &'a IMAGE_EXPORT_DIRECTORY
pub fn image(&self) -> &'a IMAGE_EXPORT_DIRECTORY
Returns the underlying export directory image.
Sourcepub fn ordinal_base(&self) -> u16
pub fn ordinal_base(&self) -> u16
Gets the ordinal base for the exported functions.
Sourcepub fn name_indices(&self) -> &'a [u16]
pub fn name_indices(&self) -> &'a [u16]
Gets the name index table.
Sourcepub fn check_sorted(&self) -> Result<bool>
pub fn check_sorted(&self) -> Result<bool>
Validates and checks if the name table is sorted.
Sourcepub fn name_linear<S: AsRef<[u8]> + ?Sized>(
&self,
name: &S,
) -> Result<Export<'a>>
pub fn name_linear<S: AsRef<[u8]> + ?Sized>( &self, name: &S, ) -> Result<Export<'a>>
Looks up an Export by its name.
Sourcepub fn name<S: AsRef<[u8]> + ?Sized>(&self, name: &S) -> Result<Export<'a>>
pub fn name<S: AsRef<[u8]> + ?Sized>(&self, name: &S) -> Result<Export<'a>>
Looks up an Export by its name.
Sourcepub fn import(&self, import: Import<'_>) -> Result<Export<'a>>
pub fn import(&self, import: Import<'_>) -> Result<Export<'a>>
Looks up an Export by its import.
Sourcepub fn hint_name<S: AsRef<[u8]> + ?Sized>(
&self,
hint: usize,
name: &S,
) -> Result<Export<'a>>
pub fn hint_name<S: AsRef<[u8]> + ?Sized>( &self, hint: usize, name: &S, ) -> Result<Export<'a>>
Looks up an export by its hint and falls back to the name if the hint is incorrect.
Sourcepub fn name_of_hint(&self, hint: usize) -> Result<&'a CStr>
pub fn name_of_hint(&self, hint: usize) -> Result<&'a CStr>
Looks up the name for a hint.
Sourcepub fn name_lookup(&self, index: usize) -> Result<Import<'a>>
pub fn name_lookup(&self, index: usize) -> Result<Import<'a>>
Given an index in the functions array, gets the named export.
Sourcepub fn iter<'s>(
&'s self,
) -> impl 's + Clone + Iterator<Item = Result<Export<'a>>>
pub fn iter<'s>( &'s self, ) -> impl 's + Clone + Iterator<Item = Result<Export<'a>>>
Iterate over exported functions.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Pe32, Pe64>
Convenient way to get an exported address.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Pe32, Pe64>
Convenient way to get an exported address.
Sourcepub fn get_export_by_ordinal(&self, ordinal: u16) -> Result<Export<'a>>
pub fn get_export_by_ordinal(&self, ordinal: u16) -> Result<Export<'a>>
Convenient method to get an exported function by ordinal.
Sourcepub fn get_export_by_import(&self, import: Import<'a>) -> Result<Export<'a>>
pub fn get_export_by_import(&self, import: Import<'a>) -> Result<Export<'a>>
Convenient method to get an exported function by import.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Imports<'a, Pe32>, Imports<'a, Pe64>>
Import directory.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Imports<'a, Pe32>, Imports<'a, Pe64>>
Import directory.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Desc<'a, Pe32>, Desc<'a, Pe64>>
Import library descriptor.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Desc<'a, Pe32>, Desc<'a, Pe64>>
Import library descriptor.
Sourcepub fn image(&self) -> &'a IMAGE_IMPORT_DESCRIPTOR
pub fn image(&self) -> &'a IMAGE_IMPORT_DESCRIPTOR
Returns the underlying import descriptor image.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<LoadConfig<'a, Pe32>, LoadConfig<'a, Pe64>>
Load Config Directory.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<LoadConfig<'a, Pe32>, LoadConfig<'a, Pe64>>
Load Config Directory.
Sourcepub fn image(
&self,
) -> Wrap<&'a IMAGE_LOAD_CONFIG_DIRECTORY32, &'a IMAGE_LOAD_CONFIG_DIRECTORY64> ⓘ
pub fn image( &self, ) -> Wrap<&'a IMAGE_LOAD_CONFIG_DIRECTORY32, &'a IMAGE_LOAD_CONFIG_DIRECTORY64> ⓘ
Returns the underlying load config directory image.
Gets the default security cookie for the image.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Tls<'a, Pe32>, Tls<'a, Pe64>>
TLS Directory.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Tls<'a, Pe32>, Tls<'a, Pe64>>
TLS Directory.
Sourcepub fn image(
&self,
) -> Wrap<&'a IMAGE_TLS_DIRECTORY32, &'a IMAGE_TLS_DIRECTORY64> ⓘ
pub fn image( &self, ) -> Wrap<&'a IMAGE_TLS_DIRECTORY32, &'a IMAGE_TLS_DIRECTORY64> ⓘ
Returns the underlying TLS directory image.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Debug<'a, Pe32>, Debug<'a, Pe64>>
Debug directory.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Debug<'a, Pe32>, Debug<'a, Pe64>>
Debug directory.
Sourcepub fn image(&self) -> &'a [IMAGE_DEBUG_DIRECTORY]
pub fn image(&self) -> &'a [IMAGE_DEBUG_DIRECTORY]
Returns the underlying debug directories image.
Sourcepub fn pdb_file_name(&self) -> Option<&'a CStr>
pub fn pdb_file_name(&self) -> Option<&'a CStr>
Gets the CodeView PDB file name.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Dir<'a, Pe32>, Dir<'a, Pe64>>
Debug directory entry.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Dir<'a, Pe32>, Dir<'a, Pe64>>
Debug directory entry.
Sourcepub fn image(&self) -> &'a IMAGE_DEBUG_DIRECTORY
pub fn image(&self) -> &'a IMAGE_DEBUG_DIRECTORY
Gets the underlying debug directory image.
Sourceimpl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Scanner<Pe32>, Scanner<Pe64>>
Pattern scanner.
impl<'a, Pe32: Pe<'a>, Pe64: Pe<'a>> Wrap<Scanner<Pe32>, Scanner<Pe64>>
Pattern scanner.
Sourcepub fn finds(&self, pat: &[Atom], range: Range<u32>, save: &mut [u32]) -> bool
pub fn finds(&self, pat: &[Atom], range: Range<u32>, save: &mut [u32]) -> bool
Finds the unique match for the pattern in the given range.
Sourcepub fn finds_code(&self, pat: &[Atom], save: &mut [u32]) -> bool
pub fn finds_code(&self, pat: &[Atom], save: &mut [u32]) -> bool
Finds the unique code match for the pattern.
Sourcepub fn matches<'pat>(
&self,
pat: &'pat [Atom],
range: Range<u32>,
) -> Wrap<Matches<'pat, Pe32>, Matches<'pat, Pe64>> ⓘ
pub fn matches<'pat>( &self, pat: &'pat [Atom], range: Range<u32>, ) -> Wrap<Matches<'pat, Pe32>, Matches<'pat, Pe64>> ⓘ
Returns an iterator over the matches of a pattern within the given range.